==> huaweicloudsdkvpc-3.1.138-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/traffic_mirror_sources_option.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TrafficMirrorSourcesOption:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'traffic_mirror_sources': 'list[str]'
    }

    attribute_map = {
        'traffic_mirror_sources': 'traffic_mirror_sources'
    }

    def __init__(self, traffic_mirror_sources=None):
        """TrafficMirrorSourcesOption

        The model defined in huaweicloud sdk

        :param traffic_mirror_sources: 功能说明：镜像源ID列表
        :type traffic_mirror_sources: list[str]
        """
        
        

        self._traffic_mirror_sources = None
        self.discriminator = None

        self.traffic_mirror_sources = traffic_mirror_sources

    @property
    def traffic_mirror_sources(self):
        """Gets the traffic_mirror_sources of this TrafficMirrorSourcesOption.

        功能说明：镜像源ID列表

        :return: The traffic_mirror_sources of this TrafficMirrorSourcesOption.
        :rtype: list[str]
        """
        return self._traffic_mirror_sources

    @traffic_mirror_sources.setter
    def traffic_mirror_sources(self, traffic_mirror_sources):
        """Sets the traffic_mirror_sources of this TrafficMirrorSourcesOption.

        功能说明：镜像源ID列表

        :param traffic_mirror_sources: The traffic_mirror_sources of this TrafficMirrorSourcesOption.
        :type traffic_mirror_sources: list[str]
        """
        self._traffic_mirror_sources = traffic_mirror_sources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TrafficMirrorSourcesOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/traffic_mirror_sources_option.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TrafficMirrorSourcesOption:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'traffic_mirror_sources': 'list[str]'
    }

    attribute_map = {
        'traffic_mirror_sources': 'traffic_mirror_sources'
    }

    def __init__(self, traffic_mirror_sources=None):
        r"""TrafficMirrorSourcesOption

        The model defined in huaweicloud sdk

        :param traffic_mirror_sources: 功能说明：镜像源ID列表
        :type traffic_mirror_sources: list[str]
        """
        
        

        self._traffic_mirror_sources = None
        self.discriminator = None

        self.traffic_mirror_sources = traffic_mirror_sources

    @property
    def traffic_mirror_sources(self):
        r"""Gets the traffic_mirror_sources of this TrafficMirrorSourcesOption.

        功能说明：镜像源ID列表

        :return: The traffic_mirror_sources of this TrafficMirrorSourcesOption.
        :rtype: list[str]
        """
        return self._traffic_mirror_sources

    @traffic_mirror_sources.setter
    def traffic_mirror_sources(self, traffic_mirror_sources):
        r"""Sets the traffic_mirror_sources of this TrafficMirrorSourcesOption.

        功能说明：镜像源ID列表

        :param traffic_mirror_sources: The traffic_mirror_sources of this TrafficMirrorSourcesOption.
        :type traffic_mirror_sources: list[str]
        """
        self._traffic_mirror_sources = traffic_mirror_sources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TrafficMirrorSourcesOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
